﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Data.OleDb;
using Syncfusion.Drawing;
using Syncfusion.Windows.Forms;
using Syncfusion.Windows.Forms.Chart;

namespace WindowsProjectChart
{
    public partial class Form1 : Form
    {
        private Random rnd;
        private DateTime d;
        private string tableName = "SNP";
        private ChartDataBindModel model;
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            InitializeControlSettings();
            InitializeChartData();

        }
        private void InitializeControlSettings()
        {
            this.chartControl1.Font = new System.Drawing.Font("Arial", 8F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
            this.chartControl1.ChartArea.PrimaryXAxis.HidePartialLabels = true;

            this.chartControl1.BackInterior = new BrushInfo(Color.LightSteelBlue);
            this.chartControl1.ChartArea.BackInterior = new BrushInfo(Color.Transparent);
            this.chartControl1.ChartInterior = new Syncfusion.Drawing.BrushInfo(Syncfusion.Drawing.GradientStyle.Vertical, new System.Drawing.Color[] { Color.FromArgb(200, 217, 242), Color.FromArgb(237, 242, 250), Color.FromArgb(200, 217, 242), Color.FromArgb(237, 242, 250), Color.White });

            this.chartControl1.BorderAppearance.SkinStyle = Syncfusion.Windows.Forms.Chart.ChartBorderSkinStyle.Emboss;


            this.chartControl1.PrimaryXAxis.GridLineType.ForeColor = Color.FromArgb(122, 188, 232);
            this.chartControl1.PrimaryYAxis.GridLineType.ForeColor = Color.FromArgb(122, 188, 232);
            this.chartControl1.PrimaryXAxis.GridLineType.DashStyle = System.Drawing.Drawing2D.DashStyle.Dot;
            this.chartControl1.PrimaryYAxis.GridLineType.DashStyle = System.Drawing.Drawing2D.DashStyle.Dot;

            this.chartControl1.PrimaryXAxis.LineType.ForeColor = Color.LightSteelBlue;
            this.chartControl1.PrimaryYAxis.LineType.ForeColor = Color.LightSteelBlue;
            this.chartControl1.PrimaryXAxis.TickColor = Color.Transparent;
            this.chartControl1.PrimaryYAxis.TickColor = Color.Transparent;

            this.dataGrid1.ReadOnly = true;
            this.dataGrid1.CaptionVisible = false;
            this.dataGrid1.PreferredColumnWidth = 63;
            this.dataGrid1.PreferredRowHeight = 7;
            this.dataGrid1.HeaderBackColor = Color.FromArgb(229, 234, 241);
            this.dataGrid1.BackColor = Color.FromArgb(239, 239, 239);
            this.dataGrid1.BorderStyle = BorderStyle.None;
            this.dataGrid1.RowHeadersVisible = false;
        }
        private void InitializeChartData()
        {
            string fileName = WinFormsUtils.FindFile(@"..\..\..\..\..\WindowsProjectChart\", "SNP.csv");

            OleDbConnection csvConn = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" + Application.StartupPath + ";Extended Properties=\"Text;HDR=Yes;FMT=Delimited\"");
            csvConn.Open();

            //Query for retriving the data from the csv file.
            string query = "Select * From " + fileName;

            OleDbCommand csvCommand = new OleDbCommand(query, csvConn);

            OleDbDataReader csvReader = csvCommand.ExecuteReader(CommandBehavior.CloseConnection);

            //Load the contents to a dataset.
            DataSet csvDataSet = ConvertToDataSet(csvReader, "CSVTable");

            //Bind the dataset with the datagrid to display the chart data.
            this.dataGrid1.SetDataBinding(csvDataSet, "CSVTable");

            this.chartControl1.Indexed = false;

            //Initializes new chart series.
            ChartSeries series = new ChartSeries("Series",ChartSeriesType.Candle);
            series.Name = tableName;

            model = new ChartDataBindModel(csvDataSet, "CSVTable");
            model.XName = "Date";
            model.YNames = new string[] { "Open","High","Low","Close" };

            series.SeriesModel = model;

            //Adds the series to the ChartSeriesCollection.
            this.chartControl1.Series.Add(series);

            ////Specifies the column width mode for the Column Type chart.
            //this.chartControl1.ColumnWidthMode = ChartColumnWidthMode.FixedWidthMode;

            //Close the connection.
            csvReader.Close();
            csvConn.Close();

        }
        protected DataSet ConvertToDataSet(OleDbDataReader dataReader, string tableName)
        {
            DataSet dataSet = new DataSet();
            do
            {
                // Create new data table

                DataTable schemaTable = dataReader.GetSchemaTable();
                DataTable dataTable = new DataTable(tableName);

                if (schemaTable != null)
                {
                    // A query returning records was executed

                    for (int i = 0; i < schemaTable.Rows.Count; i++)
                    {
                        DataRow dataRow = schemaTable.Rows[i];
                        // Create a column name that is unique in the data table
                        string columnName = (string)dataRow["ColumnName"]; //+ "<C" + i + "/>";
                        // Add the column definition to the data table
                        DataColumn column = new DataColumn(columnName, (Type)dataRow["DataType"]);

                        dataTable.Columns.Add(column);
                    }

                    //Add the data table to the dataset.
                    dataSet.Tables.Add(dataTable);

                    // Fill the data table.
                    while (dataReader.Read())
                    {
                        DataRow dataRow = dataTable.NewRow();

                        for (int i = 0; i < dataReader.FieldCount; i++)
                            dataRow[i] = dataReader.GetValue(i);

                        dataTable.Rows.Add(dataRow);
                    }
                }
                else
                {
                    // No records were returned.

                    DataColumn column = new DataColumn("RowsAffected");
                    dataTable.Columns.Add(column);
                    dataSet.Tables.Add(dataTable);
                    DataRow dataRow = dataTable.NewRow();
                    dataRow[0] = dataReader.RecordsAffected;
                    dataTable.Rows.Add(dataRow);
                }
            }
            while (dataReader.NextResult());
            return dataSet;
        }
    }
}
           
  
